@@ -6,7 +6,7 @@ use strict;
 use 5.008003;
 no warnings 'utf8';
 
-our $VERSION = '2.010';
+our $VERSION = '2.011';
 
 use File::Spec::Functions qw( catfile );
 
@@ -42,7 +42,6 @@ sub choose_subquery {
     my $driver = $sf->{d}{driver};
     my $db = $sf->{d}{db};
     my $saved_subqueries = $h_ref->{$driver}{$db} || []; # reverse
-    #my $tmp_subqueries = $sf->__fill_history_stmts( $sf->{i}{stmt_history} );
     my $tmp_subqueries;
     for my $stmt ( @{$sf->{i}{stmt_history}} ) {
         my $filled = $ax->fill_stmt( @$stmt, 1 );
@@ -93,24 +92,6 @@ sub __choose_see_long {
 }
 
 
-#sub __fill_history_stmts {
-#    my ( $sf, $subqueries ) = @_;
-#    my $filled_subqueries = [];
-#    my $rx_placeholder = qr/(?<=(?:,|\s|\())\?(?=(?:,|\s|\)|$))/;
-#    for my $e ( @$subqueries ) {
-#        my $stmt = $e->[0];
-#        for my $arg ( @{$e->[1]} ) {
-#            $arg = $sf->{d}{dbh}->quote( $arg );
-#            $stmt =~ s/$rx_placeholder/$arg/;
-#        }
-#        if ( ! $stmt =~ $rx_placeholder ) {
-#            push @$filled_subqueries, $stmt;
-#        }
-#    }
-#    return $filled_subqueries;
-#}
-
-
 sub edit_sq_file {
     my ( $sf ) = @_;
     my $ax = App::DBBrowser::Auxil->new( $sf->{i}, $sf->{o}, $sf->{d} );
@@ -157,7 +138,6 @@ sub edit_sq_file {
 sub __add_subqueries {
     my ( $sf, $subqueries ) = @_;
     my $ax = App::DBBrowser::Auxil->new( $sf->{i}, $sf->{o}, $sf->{d} );
-    #my $available = $sf->__fill_history_stmts( $sf->{i}{stmt_history} );
     my $available;
     for my $stmt ( @{$sf->{i}{stmt_history}} ) {
         my $filled = $ax->fill_stmt( @$stmt, 1 );
@@ -292,7 +272,7 @@ sub __remove_subqueries {
     my $prompt = "\n" . 'Choose:';
     my $idx = choose_a_subset(
         $subqueries,
-        { mouse => $sf->{o}{table}{mouse}, index => 1, show_fmt => 1, keep_chosen => 0, prompt => $prompt,
+        { mouse => $sf->{o}{table}{mouse}, index => 1, fmt_chosen => 1, remove_chosen => 1, prompt => $prompt,
           info => $info, back => '  BACK', confirm => '  CONFRIM', prefix => '- ' }
     );
     if ( ! defined $idx || ! @$idx ) {
